<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box">
      <div class="drag-left">
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu"></i> 区域管理目录
          </div>
          <div class="common-tree-content">
            <el-tree
              highlight-current
              v-if="treeData.length"
              :data="treeData"
              :props="defaultProps"
              :expand-on-click-node="false"
              @node-click="handleNodeClick"
              default-expand-all
            >
              <span class="custom-tree-node" slot-scope="{node, data}">
                <span>
                  <i
                    v-if="data.type == 0"
                    class="tree-node-icon el-icon-menu"
                  ></i>
                  <i
                    v-if="data.type == 1"
                    class="tree-node-icon el-icon-collection-tag"
                  ></i>
                  <i
                    v-if="data.type == 2"
                    class="tree-node-icon el-icon-office-building"
                  ></i>
                  <i
                    v-if="data.type == 3"
                    class="tree-node-icon el-icon-film"
                  ></i>
                  <i
                    v-if="data.type == 4"
                    class="tree-node-icon el-icon-copy-document"
                  ></i>
                  <i
                    v-if="data.type == 5"
                    class="tree-node-icon el-icon-discover"
                  ></i>
                  {{ node.label }}
                </span>
              </span>
            </el-tree>
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏">⋮</div>
      <div class="drag-mid">
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="6">
                    <el-form-item label="区域名称">
                      <el-input
                        maxlength="64"
                        clearable
                        placeholder="请输入区域名称"
                        v-model="querys[0].value"
                      >
                      </el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="区域编码">
                      <el-input
                        maxlength="64"
                        clearable
                        placeholder="请输入区域编码"
                        v-model="querys[1].value"
                      >
                      </el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button
                      type="primary"
                      icon="el-icon-search"
                      @click="handleSearch"
                      >搜索
                    </el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset"
                      >重置
                    </el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div class="bbsl-table-content" ref="contentPanel">
              <div class="bbsl-btn-content" ref="btnPanel">
                <el-button icon="el-icon-plus" type="primary" @click="handleAdd"
                  >新增
                </el-button>
                <el-popconfirm
                  title="确定删除选中数据吗？"
                  @confirm="handleDelete"
                >
                  <el-button
                    slot="reference"
                    :disabled="!multipleSelection.length"
                    icon="el-icon-delete"
                    type="danger"
                    style="margin-left: 10px"
                    >删除
                  </el-button>
                </el-popconfirm>
              </div>
              <el-table
                border
                size="mini"
                v-loading="loading"
                ref="multipleSelection"
                :data="tableData"
                :style="{width: '100%'}"
                :max-height="tableMaxHeight"
                :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}"
                @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange"
              >
                <el-table-column type="selection" width="55"></el-table-column>
                <el-table-column
                  fixed
                  type="index"
                  width="55"
                  label="序号"
                ></el-table-column>
                <el-table-column
                  fixed
                  min-width="200"
                  prop="name"
                  label="区域名称"
                  show-overflow-tooltip
                ></el-table-column>
                <el-table-column
                  min-width="100"
                  prop="code"
                  label="区域编码"
                  show-overflow-tooltip
                >
                </el-table-column>
                <el-table-column
                  min-width="100"
                  prop="shortName"
                  label="区域简称"
                  show-overflow-tooltip
                >
                </el-table-column>
                <el-table-column
                  width="120"
                  prop="type"
                  label="区域类型"
                  show-overflow-tooltip
                >
                  <template slot-scope="scope">
                    <template v-for="item in areaType">
                      <el-tag
                        type="success"
                        :key="item.value"
                        v-if="scope.row.type == item.value"
                        >{{ item.name }}
                      </el-tag>
                    </template>
                  </template>
                </el-table-column>
                <el-table-column
                  min-width="200"
                  prop="memo"
                  label="备注"
                  show-overflow-tooltip
                ></el-table-column>
              </el-table>
              <el-pagination
                align="right"
                background
                class="bbsl-pagination"
                ref="paginationPanel"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page"
                :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="total"
              ></el-pagination>
              <region-manage-dialog
                ref="formModal"
                @reload="reload"
              ></region-manage-dialog>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>
<script>
import {dragControllerDiv} from '@/mixins/dragControllerDiv'
import {TableMixin} from '@/mixins/tableMixin'
import regionManageDialog from '@/views/Device/resourceManage/components/regionManageDialog'
import resourceManage from '@/api/device/resourceManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'RegionManage',
  components: {
    regionManageDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/baseArea/'
      },
      areaType: [],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'RIGHT_LIKE',
          parentGroup: '',
          property: 'parentId',
          relation: 'AND',
          value: '0'
        }
      ],
      treeData: [],
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      treeNode: null
    }
  },
  created() {
    this.areaType = dictUtils.getDictItemsFromCache('qylx')
  },
  mounted() {
    dragControllerDiv()
    this.loadTree()
  },
  methods: {
    handleDeleteAfter() {
      this.loadTree()
    },
    reload() {
      this.treeNode = null
      this.loadTree()
      this.loadData()
    },
    handleAdd() {
      if (!this.treeNode) {
        this.$message.warning('请选择上级区域！')
        return
      }
      this.$refs.formModal.add(this.treeNode)
    },
    handleUpdate(row) {
      this.$refs.formModal.edit(row, this.treeNode)
    },
    handleNodeClick(data) {
      this.treeNode = data
      this.querys[2].value = this.treeNode.id
      this.loadData(1)
    },
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = this.querys[2].value ? this.querys[2].value : 0
    },
    formatData(rows) {
      rows.forEach(row => {
        let types = row.areaType.split(',')
        let temp = types.map(item => {
          let name
          this.areaType.forEach(dictItem => {
            if (dictItem.value == item) {
              name = dictItem.name
            }
          })
          return name
        })
        row.areaTypeShow = temp
      })
      return rows
    },
    loadTree() {
      this.treeData = []
      resourceManage.loadAreaTree(
        {
          id: '0'
        },
        res => {
          this.treeData = res.value // this.formatData(res.rows)
          this.$set(this.treeData)
        }
      )
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      this.queryParam.sorter = [{direction: 'ASC', property: 'sn_'}]
      resourceManage.loadArea(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.common-tree-container {
  width: 100% !important;
}

.common-tree-container ::v-deep .el-tree {
  border: none;
}

::v-deep .el-tree-node__content {
  .el-tree-node__expand-icon {
    font-size: 14px;
  }
}

::v-deep .custom-tree-node {
  span {
    font-size: 14px !important;
  }
}

::v-deep .el-tree-node > .el-tree-node__children {
  overflow: visible;
}
</style>
